@@ -92,7 +92,7 @@ def setContainerItems(graph, node, predicate, values, newtype=RDF.Seq):
             graph.add((container, RDF.type, newtype))
         i = 1
         for value in values:
-            graph.add(container, URIRef(makeContainerItemPredicate(i)), value)
+            graph.add((container, URIRef(makeContainerItemPredicate(i)), value))
             i += 1
     else:
         container = getvalue(graph, node, predicate)
